@@ -29,14 +29,11 @@
 #define _DDD_StringStringAssoc_h
 
 #include "base/strclass.h"
-#include "SourceO.h"
 #include "Assoc.h"
 
 typedef Assoc<string, string>       StringStringAssoc;
-typedef Assoc<string, SourceOrigin> StringOriginAssoc;
 
 typedef AssocIter<string, string>       StringStringAssocIter;
-typedef AssocIter<string, SourceOrigin> StringOriginAssocIter;
 
 #endif // _DDD_StringStringAssoc_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
